package VMOMI::HostLicensableResourceKey;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
